@@ -54,15 +54,13 @@ class TestOvercloudUpdatePrepare(fakes.TestOvercloudUpdatePrepare):
         mock_stack = mock.Mock()
         mock_stack.stack_name = 'overcloud'
         mock_get_stack.return_value = mock_stack
-        mock_abspath.return_value = '/home/fake/my-fake-registry.yaml'
         mock_yaml.return_value = {'fake_container': 'fake_value'}
 
-        argslist = ['--stack', 'overcloud', '--templates',
-                    '--container-registry-file', 'my-fake-registry.yaml']
+        argslist = ['--stack', 'overcloud', '--templates']
+
         verifylist = [
             ('stack', 'overcloud'),
             ('templates', constants.TRIPLEO_HEAT_TEMPLATES),
-            ('container_registry_file', 'my-fake-registry.yaml')
         ]
 
         parsed_args = self.check_parser(self.cmd, argslist, verifylist)
@@ -74,9 +72,6 @@ class TestOvercloudUpdatePrepare(fakes.TestOvercloudUpdatePrepare):
             mock_update.assert_called_once_with(
                 self.app.client_manager,
                 container='overcloud',
-                container_registry={'fake_container': 'fake_value'},
-                ceph_ansible_playbook='/usr/share/ceph-ansible'
-                                      '/site-docker.yml.sample'
             )
 
     @mock.patch('tripleoclient.workflows.package_update.update',
@@ -90,14 +85,11 @@ class TestOvercloudUpdatePrepare(fakes.TestOvercloudUpdatePrepare):
     def test_update_failed(self, mock_deploy, mock_copy, mock_yaml,
                            mock_abspath, mock_open, mock_update):
         mock_update.side_effect = exceptions.DeploymentError()
-        mock_abspath.return_value = '/home/fake/my-fake-registry.yaml'
         mock_yaml.return_value = {'fake_container': 'fake_value'}
-        argslist = ['--stack', 'overcloud', '--templates',
-                    '--container-registry-file', 'my-fake-registry.yaml']
+        argslist = ['--stack', 'overcloud', '--templates', ]
         verifylist = [
             ('stack', 'overcloud'),
             ('templates', constants.TRIPLEO_HEAT_TEMPLATES),
-            ('container_registry_file', 'my-fake-registry.yaml')
         ]
         parsed_args = self.check_parser(self.cmd, argslist, verifylist)
 
@@ -152,6 +144,7 @@ class TestOvercloudUpdateRun(fakes.TestOvercloudUpdateRun):
                 playbook='fake-playbook.yaml',
                 ansible_queue_name=constants.UPDATE_QUEUE,
                 node_user='tripleo-admin',
+                tags='',
                 skip_tags=''
             )
 
@@ -182,6 +175,7 @@ class TestOvercloudUpdateRun(fakes.TestOvercloudUpdateRun):
                     playbook=book,
                     ansible_queue_name=constants.UPDATE_QUEUE,
                     node_user='heat-admin',
+                    tags='',
                     skip_tags=''
                 )
 
@@ -211,6 +205,7 @@ class TestOvercloudUpdateRun(fakes.TestOvercloudUpdateRun):
                     playbook=book,
                     ansible_queue_name=constants.UPDATE_QUEUE,
                     node_user='heat-admin',
+                    tags='',
                     skip_tags=''
                 )
 
