@@ -45,10 +45,84 @@ from heatclient import exc as hc_exc
 from six.moves.urllib import error as url_error
 from six.moves.urllib import request
 
-
+from tripleoclient import constants
 from tripleoclient import exceptions
 
 
+def run_ansible_playbook(logger,
+                         workdir,
+                         playbook,
+                         inventory,
+                         ansible_config=None,
+                         retries=True,
+                         connection='smart',
+                         output_callback='json'):
+    """Simple wrapper for ansible-playbook
+
+    :param logger: logger instance
+    :type logger: Logger
+
+    :param workdir: location of the playbook
+    :type workdir: String
+
+    :param playbook: playbook filename
+    :type playbook: String
+
+    :param inventory: either proper inventory file, or a coma-separated list
+    :type inventory: String
+
+    :param ansible_config: Pass either Absolute Path, or None to generate a
+    temporary file, or False to not manage configuration at all
+    :type ansible_config: String
+
+    :param retries: do you want to get a retry_file?
+    :type retries: Boolean
+
+    :param connect: connection type (local, smart, etc)
+    :type connect: String
+
+    :param output_callback: Callback for output format. Defaults to "json"
+    :type output_callback: String
+    """
+    env = os.environ.copy()
+    cleanup = False
+    if ansible_config is None:
+        _, tmp_config = tempfile.mkstemp(prefix=playbook, suffix='ansible.cfg')
+        with open(tmp_config, 'w+') as f:
+            f.write("[defaults]\nstdout_callback = %s\n" % output_callback)
+            if not retries:
+                f.write("retry_files_enabled = False\n")
+            f.close()
+        env['ANSIBLE_CONFIG'] = tmp_config
+        cleanup = True
+
+    elif os.path.isabs(ansible_config):
+        if os.path.exists(ansible_config):
+            env['ANSIBLE_CONFIG'] = ansible_config
+        else:
+            raise RuntimeError('No such configuration file: %s' %
+                               ansible_config)
+    elif os.path.exists(os.path.join(workdir, ansible_config)):
+        env['ANSIBLE_CONFIG'] = os.path.join(workdir, ansible_config)
+
+    play = os.path.join(workdir, playbook)
+
+    if os.path.exists(play):
+        cmd = ['ansible-playbook',
+               '-i', inventory,
+               '-c', connection, play
+               ]
+        proc = run_command_and_log(logger, cmd, env=env, retcode_only=False)
+        proc.wait()
+        cleanup and os.unlink(tmp_config)
+        if proc.returncode != 0:
+            raise RuntimeError(proc.stdout.read())
+        return proc.returncode
+    else:
+        cleanup and os.unlink(tmp_config)
+        raise RuntimeError('No such playbook: %s' % play)
+
+
 def bracket_ipv6(address):
     """Put a bracket around address if it is valid IPv6
 
@@ -948,7 +1022,7 @@ def process_multiple_environments(created_env_files, tht_root,
 
 def run_update_ansible_action(log, clients, nodes, inventory, playbook,
                               queue, all_playbooks, action, ssh_user,
-                              skip_tags=''):
+                              tags='', skip_tags=''):
     playbooks = [playbook]
     if playbook == "all":
         playbooks = all_playbooks
@@ -956,7 +1030,8 @@ def run_update_ansible_action(log, clients, nodes, inventory, playbook,
         log.debug("Running ansible playbook %s " % book)
         action.update_ansible(clients, nodes=nodes, inventory_file=inventory,
                               playbook=book, ansible_queue_name=queue,
-                              node_user=ssh_user, skip_tags=skip_tags)
+                              node_user=ssh_user, tags=tags,
+                              skip_tags=skip_tags)
 
 
 def prepend_environment(environment_files, templates_dir, environment):
@@ -976,21 +1051,6 @@ def prepend_environment(environment_files, templates_dir, environment):
     return environment_files
 
 
-def load_container_registry(log, path):
-    registry = None
-    if path:
-        with open(os.path.abspath(path)) as content:
-            registry = yaml.load(content.read())
-    else:
-        log.warning(_(
-            "You have not provided a container registry file. Note "
-            "that none of the containers on your environment will be "
-            "updated. If you want to update your containers you have "
-            "to re-run this command and provide the registry file "
-            "with: --container-registry-file option."))
-    return registry
-
-
 def get_short_hostname():
     """Returns the local short hostname
 
@@ -1057,37 +1117,44 @@ def bulk_symlink(log, src, dst, tmpd='/tmp'):
         shutil.rmtree(tmp, ignore_errors=True)
 
 
-def run_command_and_log(log, cmd, cwd=None):
+def run_command_and_log(log, cmd, cwd=None, env=None, retcode_only=True):
     """Run command and log output
 
     :param log: logger instance for logging
     :type log: Logger
 
     :param cmd: command in list form
-    :param cmd: List
+    :type cmd: List
 
     :param cwd: current worknig directory for execution
-    :param cmd: String
+    :type cmd: String
+
+    :param env: modified environment for command run
+    :type env: List
+
+    :param retcode_only: Returns only retcode instead or proc objec
+    :type retcdode_only: Boolean
     """
     proc = subprocess.Popen(cmd, stdout=subprocess.PIPE,
                             stderr=subprocess.STDOUT, shell=False,
-                            bufsize=1, cwd=cwd)
+                            bufsize=1, cwd=cwd, env=env)
 
-    for line in iter(proc.stdout.readline, b''):
-        # TODO(aschultz): this should probably goto a log file
-        log.warning(line.rstrip())
-    proc.stdout.close()
-    return proc.wait()
+    if retcode_only:
+        for line in iter(proc.stdout.readline, b''):
+            # TODO(aschultz): this should probably goto a log file
+            log.warning(line.rstrip())
+        proc.stdout.close()
+        return proc.wait()
+    else:
+        return proc
 
 
 def ffwd_upgrade_operator_confirm(parsed_args_yes, log):
-    print("Warning! The TripleO Fast Forward Upgrade workflow "
-          "is currently considered under development. In "
-          "particular invocations of the ffwd-upgrade cli "
-          "should be initially limited to development/test "
-          "environments. Once and if you decide to use ffwd-upgrade "
+    print("\nWarning! The TripleO Fast Forward Upgrade "
+          "workflow is a critical operation against the deployed "
+          "environment.\nOnce and if you decide to use ffwd-upgrade "
           "in production, ensure you are adequately prepared "
-          "with valid backup of your current deployment state.")
+          "with valid backup of your current deployment state.\n")
     if parsed_args_yes:
         log.debug(_("Fast forward upgrade --yes continuing"))
         print(_("Continuing fast forward upgrade"))
@@ -1100,7 +1167,7 @@ def ffwd_upgrade_operator_confirm(parsed_args_yes, log):
             pass
         response = input("Proceed with the fast forward upgrade? "
                          "Type 'yes' to continue and anything else to "
-                         "cancel. Consider using the --yes parameter if "
+                         "cancel.\nConsider using the --yes parameter if "
                          "you wish to skip this warning in future. ")
         if response != 'yes':
             log.debug(_("Fast forward upgrade cancelled on user request"))
@@ -1141,17 +1208,27 @@ def build_prepare_env(environment_files, environment_directories):
     return env
 
 
-def rel_or_abs_path(tht_root, file_path):
+def rel_or_abs_path(file_path, tht_root):
     '''Find a file, either absolute path or relative to the t-h-t dir'''
+    if not file_path:
+        return None
     path = os.path.abspath(file_path)
-    if not os.path.exists(path):
+    if not os.path.isfile(path):
         path = os.path.abspath(os.path.join(tht_root, file_path))
-    if not os.path.exists(path):
+    if not os.path.isfile(path):
         raise exceptions.DeploymentError(
             "Can't find path %s %s" % (file_path, path))
     return path
 
 
+def fetch_roles_file(roles_file, tht_path=constants.TRIPLEO_HEAT_TEMPLATES):
+    '''Fetch t-h-t roles data fromm roles_file abs path or rel to tht_path.'''
+    if not roles_file:
+        return None
+    with open(rel_or_abs_path(roles_file, tht_path)) as f:
+        return yaml.safe_load(f)
+
+
 def load_config(osloconf, path):
     '''Load oslo config from a file path. '''
     log = logging.getLogger(__name__ + ".load_config")
